@@ -43,15 +43,17 @@ class Prices:
         if ax is None:
             ax = plt.gca()
 
-        self._obj.plot(lw=2, alpha=0.7, x_compat=False, ax=ax, **kwargs)
+        self._obj.plot(lw=2, alpha=0.7, x_compat=True, ax=ax, **kwargs)
         ax.yaxis.grid(linestyle=":")
         ax.xaxis.grid(linestyle=":")
         ax.set_ylabel("")
         ax.set_xlabel("")
         ax.xaxis.grid(False)
-        plt.setp(ax.get_xticklabels(), visible=True, rotation=0, ha="center")
+        if 'label' in kwargs:
+            ax.legend(loc="best")
 
         ax.axhline(1.0, linestyle="--", color="black", lw=1)
+        ax.tick_params(axis='x', labelrotation=45)
         ax.set_ylabel("Price")
         ax.set_xlabel("Date")
         return ax
