@@ -5,7 +5,7 @@ import seaborn as sns
 
 @pd.api.extensions.register_series_accessor("returns")
 class Returns:
-    """Given a Prices Series, will build the arithmetic returns and
+    """Given a Prices Series, will build the Arithmentic Returns and
     attach several properties
     """
 
@@ -28,13 +28,24 @@ class Returns:
     def wealth_index_since(self, since=None):
         return self._obj[since:].wealth_index
 
-    @property
-    def rolling_returns(self):
-        return self._obj.rolling_returns
+    def annualized(self, ppy=252):
+        """Returns the annualized return based on the days provided.
+        This is not a property because the incoming prices are of
+        undefined periodicity.
+        """
+        comp_growth = (1 + self._obj).prod()
+        return comp_growth ** (ppy / self._obj.shape[0]) - 1
+
+    def volatility_annualized(self, ppy):
+        """Returns the annualized volatility based on the days provided.
+        This is not a property because the incoming prices are of
+        undefined periodicity.
+        """
+        return self._obj.std() * (ppy ** 0.5)
 
     @property
-    def rolling_volatility(self):
-        return self._obj.rolling_volatility
+    def srri(self):
+        return self._obj.srri
 
     def plot(self):  # pragma: no cover
         gridkw = dict(height_ratios=[5, 1])
