@@ -1,6 +1,7 @@
 import pandas as pd
 import numpy as np
 import matplotlib.pyplot as plt
+import plotly.express as px
 
 
 @pd.api.extensions.register_series_accessor("wealth_index")
@@ -53,15 +54,23 @@ class WealthIndex:
         if ax is None:
             ax = plt.gca()
 
-        self._obj.plot(lw=2, alpha=0.7, x_compat=False, ax=ax, **kwargs)
+        self._obj.plot(lw=2, alpha=0.7, x_compat=True, ax=ax, **kwargs)
         ax.yaxis.grid(linestyle=":")
         ax.xaxis.grid(linestyle=":")
         ax.set_ylabel("")
         ax.set_xlabel("")
         ax.xaxis.grid(False)
-        plt.setp(ax.get_xticklabels(), visible=True, rotation=0, ha="center")
-        ax.legend(loc="best")
+        if 'label' in kwargs:
+            ax.legend(loc="best")
 
         ax.axhline(1.0, linestyle="--", color="black", lw=1)
         ax.set_ylabel("Wealth Index")
         return ax
+
+    def plotly(self, **kwargs):  # pragma: no cover
+        fig = px.line(self._obj, **kwargs)
+        fig.update_layout(
+            title="Performance on 1$",
+            legend_title="Symbol",
+        )
+        return fig
