@@ -1,6 +1,5 @@
 import matplotlib.pyplot as plt
 import matplotlib.ticker as mtick
-import matplotlib.dates as mdates
 
 
 class ExponantiallyWeightedDownsideRisk:
@@ -24,18 +23,18 @@ class ExponantiallyWeightedDownsideRisk:
             ax = plt.gca()
 
         to_plot = self.downside_risk * 100
-        to_plot.plot(lw=2, x_compat=False, ax=ax, **kwargs)
+        to_plot.plot(lw=2, x_compat=True, ax=ax, **kwargs)
         ax.yaxis.grid(linestyle=":")
         ax.xaxis.grid(linestyle=":")
         ax.set_ylabel("")
         ax.set_xlabel("")
         ax.xaxis.grid(False)
-        plt.setp(ax.get_xticklabels(), visible=True, rotation=0, ha="center")
 
         ax.yaxis.set_major_formatter(mtick.PercentFormatter())
         ax.xaxis.set_tick_params(reset=True)
-        ax.xaxis.set_major_locator(mdates.YearLocator(1))
-        ax.xaxis.set_major_formatter(mdates.DateFormatter("%Y-%m"))
+        ax.tick_params(axis='x', labelrotation=45)
+        if 'label' in kwargs:
+            ax.legend(loc="best")
 
         ax.set_title(
             f"Exp. weighted downside risk ({self.window}) \
