@@ -2,7 +2,7 @@ import pandas as pd
 import numpy as np
 import matplotlib.pyplot as plt
 import matplotlib.ticker as mtick
-import matplotlib.dates as mdates
+import plotly.express as px
 
 
 class RollingReturns:
@@ -14,7 +14,6 @@ class RollingReturns:
         self._obj = (1 + pandas_obj).rolling(window=rolling_window).apply(
             np.prod, raw=True
         ) - 1
-        self._obj.rename("Rolling_Rets", inplace=True)
 
     @staticmethod
     def _validate(obj: pd.Series, rolling_window: int):
@@ -32,18 +31,16 @@ class RollingReturns:
             ax = plt.gca()
 
         to_plot = self._obj * 100
-        to_plot.plot(lw=2, x_compat=False, ax=ax, **kwargs)
+        to_plot.plot(lw=2, x_compat=True, ax=ax, **kwargs)
         ax.yaxis.grid(linestyle=":")
         ax.xaxis.grid(linestyle=":")
         ax.set_ylabel("")
         ax.set_xlabel("")
         ax.xaxis.grid(False)
-        plt.setp(ax.get_xticklabels(), visible=True, rotation=0, ha="center")
 
         ax.yaxis.set_major_formatter(mtick.PercentFormatter())
         ax.xaxis.set_tick_params(reset=True)
-        ax.xaxis.set_major_locator(mdates.YearLocator(1))
-        ax.xaxis.set_major_formatter(mdates.DateFormatter("%Y-%m"))
+        ax.tick_params(axis='x', labelrotation=45)
 
         ax.axhline(
             y=(to_plot.mean()),
@@ -53,7 +50,11 @@ class RollingReturns:
             label=f"Avg ({to_plot.mean():0.2f}%)",
         )
         ax.axhline(y=0, color="black", lw=0.5)
-        ax.legend(loc="best")
+        if 'label' in kwargs:
+            ax.legend(loc="best")
 
         ax.set_title(f"Rolling Returns - {self.window}", fontweight="bold")
         return ax
+
+    def plotly(self, **kwargs):  # pragma: no cover
+        return px.line(self._obj, **kwargs)
