@@ -1,7 +1,7 @@
 import pandas as pd
 import matplotlib.pyplot as plt
 import matplotlib.ticker as mtick
-import matplotlib.dates as mdates
+import plotly.express as px
 
 
 class RollingVolatility:
@@ -30,7 +30,6 @@ class RollingVolatility:
             .std()
             .apply(lambda x: x * window ** 0.5)
         )
-        self._obj.rename("Rolling_Vol", inplace=True)
 
     @staticmethod
     def _validate(obj: pd.Series, rolling_window: int, window: int):
@@ -51,18 +50,21 @@ class RollingVolatility:
             ax = plt.gca()
 
         to_plot = self._obj * 100
-        to_plot.plot(lw=2, x_compat=False, ax=ax, **kwargs)
+        to_plot.plot(lw=2, x_compat=True, ax=ax, **kwargs)
         ax.yaxis.grid(linestyle=":")
         ax.xaxis.grid(linestyle=":")
         ax.set_ylabel("")
         ax.set_xlabel("")
         ax.xaxis.grid(False)
-        plt.setp(ax.get_xticklabels(), visible=True, rotation=0, ha="center")
+        if 'label' in kwargs:
+            ax.legend(loc="best")
 
         ax.yaxis.set_major_formatter(mtick.PercentFormatter())
         ax.xaxis.set_tick_params(reset=True)
-        ax.xaxis.set_major_locator(mdates.YearLocator(1))
-        ax.xaxis.set_major_formatter(mdates.DateFormatter("%Y-%m"))
+        ax.tick_params(axis='x', labelrotation=45)
 
         ax.set_title(f"Rolling Volatility - {self.rolling_window}", fontweight="bold")
         return ax
+
+    def plotly(self, **kwargs):  # pragma: no cover
+        return px.line(self._obj, **kwargs)
